@@ -1,6 +1,6 @@
 import unittest
 import numpy as np
-from xrd_simulator.xfab import tools
+from xfab import tools
 from xrd_simulator import utils
 from scipy.spatial.transform import Rotation
 
