@@ -1,7 +1,10 @@
-import pickle
+import dill
 
 
 class PickleableObject(object):
+    """Simple super class to make any python object easily pickable to disc.
+
+    """
 
     def __init__(self):
         pass
@@ -14,7 +17,7 @@ class PickleableObject(object):
 
         """
         with open(path, "wb") as f:
-            pickle.dump(self, f, pickle.HIGHEST_PROTOCOL)
+            dill.dump(self, f, dill.HIGHEST_PROTOCOL)
 
     @classmethod
     def load(cls, path):
@@ -23,10 +26,11 @@ class PickleableObject(object):
         Args:
             path (:obj:`str`): File path at which to load, ending with the desired filename.
 
-        Warning: This function will unpickle the data from the provied path. The pickle module
+        .. warning::
+            This function will unpickle data from the provied path. The pickle module
             is not intended to be secure against erroneous or maliciously constructed data.
             Never unpickle data received from an untrusted or unauthenticated source.
 
         """
         with open(path, 'rb') as f:
-            return pickle.load(f)
+            return dill.load(f)
