@@ -1,11 +1,13 @@
+#TODO: Review docs.
 import numpy as np
 from xrd_simulator import utils
 from xrd_simulator._pickleable_object import PickleableObject
+from scipy.signal import convolve
 
 
 class Detector(PickleableObject):
 
-    """Represents a rectangular X-ray scattering flat area detection device.
+    """Represents a rectangular xray scattering flat area detection device.
 
     The detector can collect scattering as abstract objects and map them to frame numbers.
     Using a render function these abstract representation can be rendered into pixelated frames.
@@ -28,6 +30,10 @@ class Detector(PickleableObject):
         normal (:obj:`numpy array`): Detector normal.
         zmax,ymax (:obj:`numpy array`): Detector width and height.
         pixel_coordinates  (:obj:`numpy array`): Real space 3d detector pixel coordinates. ``shape=(n,3)``
+        point_spread_function  (:obj:`callable`): Scalar point spread function called as point_spread_function(z, y). The
+            z and y coordinates are assumed to be in local units of pixels. I.e point_spread_function(0, 0) returns the
+            value of the pointspread function at the location of the point being spread. This is meant to model blurring
+            due to detector optics. Defaults to a Gaussian with standard deviation 1.0 and mean at (z,y)=(0,0).
 
     Examples:
         .. literalinclude:: examples/example_init_detector.py
@@ -46,6 +52,45 @@ class Detector(PickleableObject):
         self.frames = []
         self.pixel_coordinates = self._get_pixel_coordinates()
 
+        self.point_spread_function = lambda z, y: np.exp(-0.5 * (z*z + y*y) / (1.0 * 1.0) )
+        self._point_spread_kernel_shape = (5, 5)
+
+    @property
+    def point_spread_kernel_shape(self):
+        """point_spread_kernel_shape  (:obj:`tuple`): Number of pixels in z and y over which to apply the pointspread function
+            for each scattering event. I.e the shape of the kernel that will be convolved with the diffraction pattern. The
+            values of the kernel is defined by the point_spread_function. Defaults to shape (5, 5).
+
+            NOTE: The point_spread_function is automatically normalised over the point_spread_kernel_shape domain such that the
+                final convolution over the detector diffraction pattern is intensity preserving.
+        """
+        return self._point_spread_kernel_shape
+
+    @point_spread_kernel_shape.setter
+    def point_spread_kernel_shape(self, kernel_shape):
+
+        if kernel_shape[0] % 2 == 0 or kernel_shape[1] % 2 == 0:
+            raise ValueError("Point spread function kernel shape must be odd in both dimensions, but shape "+str(kernel_shape)+" was provided.")
+        else:
+            self._point_spread_kernel_shape = kernel_shape
+
+    def _get_point_spread_function_kernel(self):
+        """Render the point_spread_function onto a grid of shape specified by point_spread_kernel_shape.
+        """
+        sz, sy = self.point_spread_kernel_shape
+        axz = np.linspace(-(sz - 1) / 2., (sz - 1) / 2., sz)
+        axy = np.linspace(-(sy - 1) / 2., (sy - 1) / 2., sy)
+        Z, Y = np.meshgrid(axz, axy, indexing='ij')
+        kernel = np.zeros(self.point_spread_kernel_shape)
+        for i in range(Z.shape[0]):
+            for j in range(Y.shape[1]):
+                kernel[i, j] = self.point_spread_function(Z[i, j], Y[i, j])
+
+        assert len( kernel[kernel<0] )==0, "Point spread function must be strictly positive, but negative values were found."
+        assert np.sum(kernel)>1e-8, "The integrated value of the point spread function over the defined kernel domain is close to zero."
+
+        return kernel / np.sum(kernel)
+
     def render(
             self,
             frame_number,
@@ -82,6 +127,7 @@ class Detector(PickleableObject):
         """
         frame = np.zeros((int(self.zmax / self.pixel_size_z),
                          int(self.ymax / self.pixel_size_y)))
+
         for si, scatterer in enumerate(self.frames[frame_number]):
 
             if verbose:
@@ -89,7 +135,7 @@ class Detector(PickleableObject):
                     str(len(self.frames[frame_number])) + " scattering volumes unto the detector"
                 progress_fraction = float(
                     si + 1) / len(self.frames[frame_number])
-                utils.print_progress(
+                utils._print_progress(
                     progress_fraction,
                     message=progress_bar_message)
 
@@ -104,13 +150,17 @@ class Detector(PickleableObject):
                     polarization,
                     structure_factor)
 
+        if self.point_spread_function is not None:
+            kernel = self._get_point_spread_function_kernel()
+            frame = convolve(frame, kernel, mode='same', method='direct')
+
         return frame
 
     def get_intersection(self, ray_direction, source_point):
         """Get detector intersection in detector coordinates of a single ray originating from source_point.
 
         Args:
-            ray_direction (:obj:`numpy array`): Vector in direction of the X-ray propagation
+            ray_direction (:obj:`numpy array`): Vector in direction of the xray propagation
             source_point (:obj:`numpy array`): Origin of the ray.
 
         Returns:
@@ -231,14 +281,18 @@ class Detector(PickleableObject):
             polarization,
             structure_factor):
         intensity_factor = 1.0
-        # TODO: Consider solid angle intensity rescaling.
+        # TODO: Consider solid angle intensity rescaling and air scattering.
         if lorentz:
             intensity_factor *= scatterer.lorentz_factor
         if polarization:
             intensity_factor *= scatterer.polarization_factor
-        if structure_factor and scatterer.real_structure_factor is not None:
-            intensity_factor *= (scatterer.real_structure_factor **
-                                 2 + scatterer.imaginary_structure_factor**2)
+        if structure_factor:
+            if scatterer.phase.structure_factors is not None:
+                intensity_factor *= (scatterer.real_structure_factor **
+                                    2 + scatterer.imaginary_structure_factor**2)
+            else:
+                raise ValueError("Structure factors have not been set, .cif file is required at sample instantiation.")
+
         return intensity_factor
 
     def _project(self, scatterer, box):
